@@ -33,6 +33,7 @@
 #include <libgnomeui/gnome-font-picker.h>
 #include <libgnomevfs/gnome-vfs-directory.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
 #include "catalog-web-exporter.h"
 #include "dlg-file-utils.h"
@@ -116,16 +117,19 @@ export (GtkWidget  *widget,
 {
 	CatalogWebExporter *exporter = data->exporter;
 	char               *location;
-	char               *path;
+	char               *esc_path, *path;
 	char               *theme, *index_file;
 	const char         *header;
 	const char         *footer;
 
 	/* Save options. */
 
-	path = _gtk_entry_get_filename_text (GTK_ENTRY (data->wa_destination_entry));
+	esc_path = _gtk_entry_get_filename_text (GTK_ENTRY (data->wa_destination_entry));
+	path = gnome_vfs_unescape_string (esc_path, "");
 	location = remove_ending_separator (path);
 	g_free (path);
+	g_free (esc_path);
+
 	eel_gconf_set_path (PREF_WEB_ALBUM_DESTINATION, location);
 
 	index_file = _gtk_entry_get_filename_text (GTK_ENTRY (data->wa_index_file_entry));
@@ -276,8 +280,7 @@ open_response_cb (GtkDialog  *file_sel,
 		  int         button_number,
 		  gpointer    userdata)
 {
-	DialogData     *data = (DialogData   * )userdata;
-	GnomeFileEntry *fentry = (GnomeFileEntry *) data;
+	DialogData  *data = (DialogData   * )userdata;
 
 	if (button_number == GTK_RESPONSE_ACCEPT) {
 		_gtk_entry_set_filename_text (GTK_ENTRY (data->wa_destination_entry),
@@ -299,7 +302,8 @@ wa_destination_button_clicked_cb (GtkWidget  *button,
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
 						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 						NULL);
-	
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
+
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
 	g_signal_connect (G_OBJECT (file_sel),
 			  "response",
@@ -324,7 +328,6 @@ dlg_web_exporter (GThumbWindow *window)
 	GtkWidget    *btn_help;
 	GList        *list;
 	char         *svalue;
-	GtkWidget    *fileentry;
 
 	data = g_new (DialogData, 1);
 
@@ -431,6 +434,10 @@ dlg_web_exporter (GThumbWindow *window)
 
 	/* Signals. */
 
+	g_signal_connect (G_OBJECT (data->dialog), 
+			  "destroy",
+			  G_CALLBACK (destroy_cb),
+			  data);
 	g_signal_connect (G_OBJECT (data->wa_destination_button), 
 			  "clicked",
 			  G_CALLBACK (wa_destination_button_clicked_cb),
@@ -745,6 +752,7 @@ theme_dialog__install_theme_clicked (GtkWidget       *widget,
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 						NULL);
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	g_object_set_data (G_OBJECT (file_sel), "theme_dialog_data", tdata);
 
 	home = g_strconcat (g_get_home_dir (), "/", NULL);
